// @flow

/* 
  You may want to use or make your own button. This one is kind of a placeholder. This library is for fields, this button is here for storybook and whatnot.
*/

import React from 'react'
import styled from 'styled-components/native'

type Props = {
  style?: string,
  textStyle?: string,
}

const { WHITE, BLUE, GREEN, BROKEN_WHITE, LIGHT_GRAY, FONT_NORMAL, FONT_BOLD } = {
  WHITE: '#ffffff',
  BLUE: '#33c3ff',
  GREEN: '#00ff60',
  BROKEN_WHITE: '#d5ffff',
  LIGHT_GRAY: '#99998a',
  FONT_NORMAL: 600,
  FONT_BOLD: 800,
}

//  Button Styles
const ButtonBase = styled.TouchableOpacity`
  background-color: ${props =>
    props.primary
      ? GREEN
      : props.secondary
      ? BLUE
      : props.tiertiary
      ? BROKEN_WHITE
      : props.disabled
      ? LIGHT_GRAY
      : GREEN}

  height: ${props => (props.large ? 48 : 36)};
  width: ${props => props.width || '100%'};
  padding: 6px 24px;
  justify-content: center;
  align-items: center;
  border-radius: 25;
  ${({ style }) => style}
`

//  Button Text Styles
const Text = styled.Text`
  color: ${props =>
    props.primary ? WHITE : props.secondary ? WHITE : props.tiertiary ? BLUE : props.disabled ? WHITE : WHITE};
  font-size: 16px;
  font-weight: ${props => (props.bold ? FONT_BOLD : FONT_NORMAL)};
  ${({ textStyle }) => textStyle}
`

const Button = (props: Props) => {
  return (
    <ButtonBase style={props.style || ''} textStyle={props.textStyle || ''} {...props}>
      {props.children && <Text {...props}>{props.children}</Text>}
    </ButtonBase>
  )
}

export default Button
