import React from 'react'
import renderer from 'react-test-renderer'
import { mount, shallow } from 'enzyme'
import getStyle from '../helpers/get-style'
import Button from './Button'

describe('Test NoContent component', () => {
  const primaryButton = renderer.create(<Button>Press me!</Button>)
  const LargePrimaryButton = renderer.create(<Button large>Press me!</Button>)
  const secondaryButton = renderer.create(<Button secondary>Press me!</Button>)
  const tiertiaryButton = renderer.create(<Button tiertiary>Press me!</Button>)
  const disabledButton = renderer.create(<Button disabled>Press me!</Button>)

  // Tests that buttons render
  test('should render', () => {
    expect(primaryButton.toJSON()).toBeTruthy()
    expect(LargePrimaryButton.toJSON()).toBeTruthy()
    expect(secondaryButton.toJSON()).toBeTruthy()
    expect(tiertiaryButton.toJSON()).toBeTruthy()
    expect(disabledButton.toJSON()).toBeTruthy()
  })
  // -------------------------------------------------------------

  // Tests that buttons render the correct background colors

  // PRIMARY BUTTON
  test('should be default background colour', async () => {
    const style = await getStyle(primaryButton.toJSON())

    expect(style.colors.backgroundColor).toBeTruthy()
  })
  // SECONDARY BUTTON
  test('should be secondary Blue background colour', async () => {
    const style = await getStyle(secondaryButton.toJSON())

    expect(style.colors.backgroundColor).toBeTruthy()
  })
  // TIERTIARY BUTTON
  test('should be tiertiary Broken White background colour', async () => {
    const style = await getStyle(tiertiaryButton.toJSON())

    expect(style.colors.backgroundColor).toBeTruthy()
  })
  // DISABLED BUTTON
  test('should be disabled Light Gray background colour', async () => {
    const style = await getStyle(disabledButton.toJSON())

    expect(style.colors.backgroundColor).toBeTruthy()
  })
  // -------------------------------------------------------------

  // Tests that buttons render the correct text colors
  // -------------------------------------------------------------

  // Tests that buttons render with the correct height

  // PRIMARY BUTTON - DEFAULT
  test('should have the default height of 36px', async () => {
    const style = await getStyle(primaryButton.toJSON())

    expect(style.height).toBe('36px')
  })

  // PRIMARY BUTTON - LARGE
  test('should have the Large prop option height of 48px', async () => {
    const style = await getStyle(LargePrimaryButton.toJSON())

    expect(style.height).toBe('48px')
  })

  // -------------------------------------------------------------

  // Tests that buttons render the correct text
  test('should show correct text', () => {
    const mounted = mount(<Button>Press me!</Button>)

    expect(mounted.text()).toBe('Press me!')
  })
})
