import React, { useState } from 'react'
import { storiesOf } from '@storybook/react-native'
import between from 'dates-between'
import moment from 'moment'
import { findKey } from 'lodash'
import { YELLOW } from '../styles/theme'
import Calendar from './Calendar'

const BasicCalendar = () => {
  const [dates, setDates] = useState({
    [moment().format('YYYY-MM-DD')]: { selected: true, startingDay: true, color: YELLOW },
  })

  /*
    dateString: "2019-09-04"

    day: 4

    month: 9

    timestamp: 1567555200000

    year: 2019
  */
  const onDayPress = date => {
    const currentStartingDay = findKey(dates, 'startingDay')
    const earliestDay = Object.keys(dates)[0]
    const startingDay = earliestDay > currentStartingDay ? earliestDay : currentStartingDay
    const datesInRange = between(new Date(startingDay), new Date(date.dateString))
    const formattedDatesInRange = {}

    for (const d of datesInRange) {
      const newDateInRange = moment(d).format('YYYY-MM-DD')
      if (!(moment(startingDay).unix() > moment(newDateInRange).unix())) {
        formattedDatesInRange[newDateInRange] = { selected: true, color: YELLOW }
      }
    }

    setDates({
      ...formattedDatesInRange,
      [startingDay]: { startingDay: true, selected: true, color: YELLOW },
      [date.dateString]: { selected: true, endingDay: true, color: YELLOW },
    })
  }

  const showPeriod = Object.keys(dates).length >= 2

  console.log('Object.keys(dates).length', Object.keys(dates).length)

  return <Calendar onDayPress={onDayPress} markedDates={dates} showPeriod={showPeriod} />
}

storiesOf('Calendar', module).add('default', () => <BasicCalendar />, {
  notes: 'This components may only work on mobile for now',
})
