import React from 'react'
import { TouchableOpacity, TouchableWithoutFeedback } from 'react-native'
import styled from 'styled-components/native'
import Icon from './Icon'

import { WHITE, BLUE, GRAY, LIGHTEST_GRAY } from '../styles/theme'

// Variants:
// unchecked: BG: WHITE       CHECKMARK: N/A    BORDER: GRAY
// checked:   BG: BLUE        CHECKMARK: WHITE  BORDER: N/A
// disabled:  BG: LIGHT_GRAY  CHECKMARK: GRAY   BORDER: GRAY

const checkMarkSize = 8

const Box = styled.View`
  background-color: ${props => (props.disabled ? LIGHTEST_GRAY : props.checked ? BLUE : WHITE)};
  width: 20;
  height: 20;
  border-radius: 2;
  justify-content: center;
  align-items: center;
`

const CheckBox = props => {
  const { checked, disabled } = props

  if (disabled) {
    return (
      <Box {...props} style={{ borderStyle: 'solid', borderWidth: 0.5, borderColor: GRAY }}>
        <Icon name="check" size={checkMarkSize} color={GRAY} />
      </Box>
    )
  }
  if (checked === true) {
    return (
      <TouchableWithoutFeedback onPress={props.handleToggle}>
        <Box {...props}>
          <Icon name="check" size={checkMarkSize} color={WHITE} />
        </Box>
      </TouchableWithoutFeedback>
    )
  }
  if (checked === false) {
    return (
      <TouchableOpacity onPress={props.handleToggle}>
        <Box {...props} style={{ borderStyle: 'solid', borderWidth: 0.5, borderColor: GRAY }} />
      </TouchableOpacity>
    )
  }
  return null
}

CheckBox.defaultProps = {
  checked: null,
  disabled: null,
}

export default CheckBox
