import React from 'react'
import renderer from 'react-test-renderer'
import { mount, shallow } from 'enzyme'
import getStyle from '../helpers/get-style'
import CheckBox from './CheckBox'

// Tiket Color imports
import { WHITE, BLUE, GRAY, LIGHTEST_GRAY } from '../styles/theme'

describe('Test CheckBox Component', () => {
  test('Buttons should NOT render when NOT passing "disabled || checked || checked={false}"', async () => {
    const wrapper = renderer.create(<CheckBox />)
    const style = await getStyle(wrapper.toJSON())

    expect(style).toBeFalsy()
  })

  test('Buttons should render', () => {
    const wrapper1 = renderer.create(<CheckBox checked />)
    const wrapper2 = renderer.create(<CheckBox checked={false} />)
    const wrapper3 = renderer.create(<CheckBox disabled />)
    expect(wrapper1.toJSON()).toBeTruthy()
    expect(wrapper2.toJSON()).toBeTruthy()
    expect(wrapper3.toJSON()).toBeTruthy()
  })

  test('Should render with the height 20', async () => {
    const wrapper1 = renderer.create(<CheckBox checked />)
    const wrapper2 = renderer.create(<CheckBox checked={false} />)
    const wrapper3 = renderer.create(<CheckBox disabled />)
    const style1 = await getStyle(wrapper1.toJSON())
    const style2 = await getStyle(wrapper2.toJSON().children[0])
    const style3 = await getStyle(wrapper3.toJSON())

    expect(style1.height).toBe('20px')
    expect(style2.height).toBe('20px')
    expect(style3.height).toBe('20px')
  })

  test('Should render with the width 20', async () => {
    const wrapper1 = renderer.create(<CheckBox checked />)
    const wrapper2 = renderer.create(<CheckBox checked={false} />)
    const wrapper3 = renderer.create(<CheckBox disabled />)
    const style1 = await getStyle(wrapper1.toJSON())
    const style2 = await getStyle(wrapper2.toJSON().children[0])
    const style3 = await getStyle(wrapper3.toJSON())

    expect(style1.width).toBe('20px')
    expect(style2.width).toBe('20px')
    expect(style3.width).toBe('20px')
  })

  test('Checked box Should have the background color Tiket Blue', async () => {
    const wrapper = renderer.create(<CheckBox checked />)
    const style = await getStyle(wrapper.toJSON())

    expect(style.colors.backgroundColor).toBe(BLUE)
  })

  test('Un-Checked box Should have the background color White', async () => {
    const wrapper = renderer.create(<CheckBox checked={false} />)
    const style = await getStyle(wrapper.toJSON().children[0])

    expect(style.colors.backgroundColor).toBe(WHITE)
  })

  test('Disabled box Should have the background color LIGHTEST_GRAY', async () => {
    const wrapper = renderer.create(<CheckBox disabled />)
    const style = await getStyle(wrapper.toJSON())

    expect(style.colors.backgroundColor).toBe(LIGHTEST_GRAY)
  })

  test('Checked-checked box should not have a border', async () => {
    const wrapper = renderer.create(<CheckBox checked />)
    const style = await getStyle(wrapper.toJSON().children[0])

    expect(style.colors.borderTopColor).toBeFalsy()
  })

  test('Un-checked box should have a border color of #C6CBDA / GRAY', async () => {
    const wrapper = renderer.create(<CheckBox checked={false} />)
    const style = await getStyle(wrapper.toJSON().children[0])

    expect(style.colors.borderTopColor).toBe(GRAY)
    expect(style.colors.borderRightColor).toBe(GRAY)
    expect(style.colors.borderBottomColor).toBe(GRAY)
    expect(style.colors.borderLeftColor).toBe(GRAY)
  })

  test('Un-checked box should have a border width of 0.5px', async () => {
    const wrapper = renderer.create(<CheckBox checked={false} />)
    const style = await getStyle(wrapper.toJSON().children[0])

    expect(style.colors.borderTopColor).toBe(GRAY)
  })

  test('Disabled box should have a border color of GRAY', async () => {
    const wrapper = renderer.create(<CheckBox disabled />)
    const style = await getStyle(wrapper.toJSON())

    expect(style.colors.borderTopColor).toBe(GRAY)
    expect(style.colors.borderRightColor).toBe(GRAY)
    expect(style.colors.borderBottomColor).toBe(GRAY)
    expect(style.colors.borderLeftColor).toBe(GRAY)
  })

  test('Disabled box should have a border width of 0.5px', async () => {
    const wrapper = renderer.create(<CheckBox disabled />)
    const style = await getStyle(wrapper.toJSON())

    expect(style.colors.borderTopColor).toBe(GRAY)
  })
})
