// @flow

/* Some fields can use the container to more easily add conistent error handling, and other functionality. */

import React from 'react'
import { View, Text, TextInput } from 'react-native'
// import validate from 'react-final-form-fields-validate'
import styled from 'styled-components/native'

const Tooltip = styled.Text`
  font-size: 12;
  line-height: 18;
  color: gray;
  margin-top: 2;
`

// import SpeechBubble from '../common/SpeechBubble'

type CommonProps = {
  children: React.Element,
  input: Object,
  meta?: Object,
  id?: string,
}

type TextFieldProps = {
  ...CommonProps,
  label: string,
  beforeElement?: any,
  onKeyUp?: () => void,
  containers?: React.Element | string,
}

const SwitchBadge = ({ status }) => <View>{status}</View>

const Container = ({
  children,
  containers = {},
  containerStyle,
  id,
  input,
  label,
  meta,
  meta: { error, touched },
  verification,
  tooltip,
  placeholder,
}: TextFieldProps) => {
  const showError = !!touched && !!error
  const {
    OuterContainer = View,
    LabelContainer = View,
    Label = Text,
    ErrorContainer = View,
    ErrorText = Text,
    FieldContainer = View,
    // FieldElement = TextInput,
  } = containers

  return (
    <OuterContainer meta={meta} id={id}>
      <LabelContainer meta={meta} htmlFor={`Checkbox_${input.name}`}>
        <Label meta={meta}>{label}</Label>
      </LabelContainer>
      <FieldContainer>
        {children}
        {verification && <SwitchBadge status={verification} />}
      </FieldContainer>
      {tooltip && <Tooltip>{tooltip}</Tooltip>}
      {showError && (
        <ErrorContainer id={`Fields_${input.name}-error`}>
          <ErrorText>{error}</ErrorText>
        </ErrorContainer>
      )}
    </OuterContainer>
  )
}

export default Container
