// @flow

import React from 'react'
import Styled from 'styled-components/native'

type propTypes = {
  ...Styled.View.propTypes,
  justifyContent?: ['flex-start', 'center', 'flex-end', 'space-around', 'space-between', 'space-evenly'],
  alignItems?: ['flex-start', 'center', 'flex-end', 'stretch'],
  backgroundColor?: string,
  pad?: string,
  width?: string,
  flex?: number,
  alignSelf?: ['auto', 'flex-start', 'flex-end', 'center', 'stretch', 'baseline'],
}

const StyledColumn = Styled.View`
  justify-content: ${props => props.justifyContent || 'center'};
  ${({ alignItems }) => alignItems && `align-items: ${alignItems};`}
  ${({ backgroundColor }) => backgroundColor && `background-color: ${backgroundColor};`}
  ${({ pad }) => pad && `padding: ${pad};`}
  ${({ flex }) => flex && `flex: ${flex};`}
  ${({ width }) => width && `width: ${width};`}
  ${({ alignSelf }) => alignSelf && `align-self: ${alignSelf};`}
  flex-direction: column;
`

const StyledRow = Styled.View`
  justify-content: ${props => props.justifyContent || 'center'};
  ${({ alignItems }) => alignItems && `align-items: ${alignItems};`}
  ${({ backgroundColor }) => backgroundColor && `background-color: ${backgroundColor};`}
  ${({ pad }) => pad && `padding: ${pad};`}
  ${({ flex }) => flex && `flex: ${flex};`}
  ${({ width }) => width && `width: ${width};`}
  ${({ alignSelf }) => alignSelf && `align-self: ${alignSelf};`}
  flex-direction: row;
`

export const Column = (props: propTypes) => <StyledColumn {...props} />
export const Row = (props: propTypes) => <StyledRow {...props} />
