import React from 'react'
import styled, { css } from 'styled-components/native'
import { GRAY, RED_SALMON, margins } from '../styles/theme'

const { default: normal, min } = margins

const TextInput = styled.TextInput`
  padding: ${({ padding }) => padding || '0px 16px'};
  border-width: ${({ borderWidth }) => borderWidth || '0.5px'};
  border-style: ${({ borderStyle }) => borderStyle || 'solid'};
  border-color: ${({ error, borderColor }) => (error ? RED_SALMON : borderColor || GRAY)};
  border-radius: ${({ radius }) => radius || '4px'};
  height: ${({ height }) => height || '44px'};
  ${({ error }) =>
    error &&
    css`
      margin-bottom: ${min}px;
    `};
`

const Text = styled.Text`
  color: ${({ color }) => color || RED_SALMON};
  font-size: ${({ size }) => size || '10px'};
`

export const Wrapper = styled.View`
  padding: 0 0 ${normal}px;
`

const Input = props => {
  const { touched, error } = props
  return (
    <Wrapper>
      <TextInput {...props} />
      {touched && error && <Text>{error}</Text>}
    </Wrapper>
  )
}

export default Input
