import React from 'react'
import { debounce } from 'lodash'
import { View, Text } from 'react-native'
import styled from 'styled-components/native'
import Button from './Button'

const RoundButton = styled(Button)`
  border-radius: 50;
  padding: 0;
  width: 36;
  border-color: gray;
  border-width: 1;
  color: gray;
  background-color: white;
  overflow: hidden;
`

const Row = styled.View`
  flex-direction: row;
  align-items: center;
  justify-content: center;
`

const buttonFiller = {
  width: 40,
  margin: 5,
}

const Stepper = ({ input, input: { onChange }, readonly = false, initial }) => {
  const addOneStep = debounce(() => {
    const nextValue = parseInt(input.value, 10) + 1 || 1
    onChange(nextValue)
  }, 100)

  const removeOneStep = debounce(() => {
    const nextValue = input.value === 0 ? 0 : input.value - 1
    onChange(nextValue)
  }, 100)

  return (
    <Row>
      <RoundButton
        onPress={removeOneStep}
        // iconStyle={whiteAndRounded}
        // buttonStyle={whiteAndRounded}
        // icon={plusIcon}
      />
      <Text
        title
        style={{
          margin: 5,
          padding: 1,
          color: '#000',
        }}
      >
        {input.value}
      </Text>
      {readonly ? (
        <View style={buttonFiller} />
      ) : (
        <RoundButton
          onPress={addOneStep}
          // iconStyle={whiteAndRounded}
          // buttonStyle={whiteAndRounded}
          // icon={plusIcon}
        />
      )}
    </Row>
  )
}

Stepper.defaultProps = {
  step: 1,
  initial: 0,
  loop: true,
  lowerLimit: 0,
  upperLimit: 10,
}

export default Stepper
