import React, { useState } from 'react'
import { TouchableWithoutFeedback, Animated } from 'react-native'
import styled from 'styled-components/native'
import { BLUE, GRAY } from '../styles/theme'

// Styling Helper functions
const getBackgroundColor = propsObject => {
  if (propsObject.on) {
    return BLUE
  }
  return GRAY
}
// Styled Components
const Toggle = styled.View`
  margin-top: 30;
  margin-left: 30;
  width: 75;
  height: 36;
  background-color: ${getBackgroundColor};
  border-radius: 20;
  justify-content: center;
  align-items: center;
  flex-direction: row;
  padding-left: ${props => (props.off ? 0 : 2)};
  padding-right: ${props => (props.off ? 2 : 0)};
`

const Label = styled.Text`
  color: white;
  font-size: 16;
`
// The Dot is an animatable view
const Dot = props => {
  // "fromValue" is the Initial start value in the x-dimension.
  const [xPosition] = useState(new Animated.Value(props.fromValue))
  // The effect function used to gradually change the x coordinate.
  // "toValue" is the end position in the x-dimension.
  React.useEffect(() => {
    Animated.timing(xPosition, {
      toValue: props.toValue,
      duration: 250,
    }).start()
  }, [])
  // Returning the animated View with styling
  return (
    <Animated.View
      style={{
        margin: 5,
        width: 26,
        height: 26,
        borderRadius: 13,
        backgroundColor: 'white',
        transform: [{ translateX: xPosition }],
      }}
    />
  )
}
// Switch component
const Switch = ({ input: { value, onChange } = {}, meta }) => {
  const handleToggle = () => onChange(!value)

  return (
    <>
      {value ? (
        <TouchableWithoutFeedback onPress={handleToggle}>
          <Toggle on>
            <Label>On</Label>
            <Dot fromValue={-33} toValue={6} />
          </Toggle>
        </TouchableWithoutFeedback>
      ) : (
        <TouchableWithoutFeedback onPress={handleToggle}>
          <Toggle off>
            <Dot fromValue={33} toValue={-6} />
            <Label off>Off</Label>
          </Toggle>
        </TouchableWithoutFeedback>
      )}
    </>
  )
}

export default Switch
