import React from 'react'
import { View } from 'react-native'
import { Form, Field } from 'react-final-form'
import { storiesOf } from '@storybook/react-native'
import styled from 'styled-components/native'
// import { isPhone } from 'react-final-form-fields-validate'

import Input from './TextField'
import * as Butt from './Button'

// color: ${({ meta }) => (meta && meta.active !== undefined ? 'blue' : meta.error ? 'pink' : 'gray')};

const Button = styled(Butt.default)`
  justify-content: center;
`

const tiketContainers = {
  OuterContainer: styled.View`
    width: 100%;
    padding-vertical: 15;
    padding-horizontal: 15;
  `,
  LabelContainer: styled.View`
    position: absolute;
    margin-left: 16;
    max-width: 100;
    overflow: visible;
    line-break: no-break;
    top: 10;
    z-index: 2;
    background-color: ${({ meta: { error } }) => (error ? 'white' : 'white')};
    justify-content: center;
    align-items: center;
    padding-horizontal: 5;
  `,
  Label: styled.Text`
    color: violet;
    font-size: 12;
    line-height: 15;
  `,
  FieldContainer: styled.View`
    margin-top: 10;
    flex-grow: 1;
    flex-direction: column;
    height: 44;
  `,
  FieldElement: styled.TextInput`
    flex-grow: 1;
    border-style: solid;
    border-bottom-width: 1;
    outline: none;
  `,
  ErrorContainer: styled.View`
    margin-vertical: 16;
    margin-horizontal: 16;
  `,
  ErrorText: styled.Text`
    color: pink;
  `,
}

const Row = styled.View`
  flex-direction: row;
  flex: 4;
`

const SmallFieldContainer = styled.View`
  margin-top: 10;
  flex: 3;
  padding-vertical: 16;
  padding-horizontal: 16;
`

const LargeFieldContainer = styled.View`
  margin-top: 10;
  flex: 5;
  padding-vertical: 16;
  padding-horizontal: 16;
`

storiesOf('Custom styles', module)
  //  Primary Button
  .add('Text type', () => (
    <Form onSubmit={console.log}>
      {({ handleSubmit }) => (
        <Field
          containers={tiketContainers}
          type="text"
          label="Username"
          name="Username"
          placeholder="Username"
          render={Input}
        />
      )}
    </Form>
  ))
  .add('Phone type', () => (
    <Form onSubmit={console.log}>
      {({ handleSubmit }) => (
        <View>
          <Field
            containers={tiketContainers}
            validate={() => 'This is a fake error'}
            label="Phone number"
            type="phone"
            name="phone"
            placeholder="Phone"
            render={Input}
          />
          <Button primary type="submit" onPress={handleSubmit}>
            Submit
          </Button>
        </View>
      )}
    </Form>
  ))
  .add('Date type', () => (
    <Form onSubmit={console.log}>
      {({ handleSubmit }) => (
        <>
          <Field
            containers={tiketContainers}
            validate={() => 'This is a fake error'}
            label="Date"
            placeholder="Date"
            type="date"
            name="date"
            render={Input}
          />
          <Button primary type="submit" onPress={handleSubmit}>
            Submit
          </Button>
        </>
      )}
    </Form>
  ))
  .add('Password type', () => (
    <Form onSubmit={console.log}>
      {({ handleSubmit }) => (
        <>
          <Field
            containers={tiketContainers}
            validate={() => 'This is a fake error'}
            placeholder="Password"
            label="Password"
            type="password"
            name="password"
            render={Input}
          />
          <Button primary type="submit" onPress={handleSubmit}>
            Submit
          </Button>
        </>
      )}
    </Form>
  ))
  .add('Full form', () => {
    return (
      <Form onSubmit={console.log}>
        {({ handleSubmit, error }) => (
          <>
            <Field
              containers={tiketContainers}
              placeholder="First name"
              label="First Name"
              name="firstname"
              type="text"
              render={Input}
            />
            <Field
              containers={tiketContainers}
              placeholder="Last name"
              label="Last Name"
              name="lastname"
              type="text"
              render={Input}
            />
            <Row>
              <Field
                containers={{ ...tiketContainers, OuterContainer: SmallFieldContainer }}
                placeholder="Country code"
                label="Country code"
                name="countryCode"
                type="phone"
                render={Input}
              />
              <Field
                containers={{ ...tiketContainers, OuterContainer: LargeFieldContainer }}
                placeholder="Phone number"
                label="Phone number"
                name="phoneNumber"
                type="text"
                render={Input}
              />
            </Row>
            <Field
              containers={tiketContainers}
              placeholder="Password"
              label="Password"
              name="passowrd"
              type="newPassword"
              render={Input}
            />
            <Button primary type="submit" onPress={handleSubmit}>
              Register
            </Button>
            {error && (
              <tiketContainers.ErrorContainer>
                <tiketContainers.ErrorText>{error}</tiketContainers.ErrorText>
              </tiketContainers.ErrorContainer>
            )}
          </>
        )}
      </Form>
    )
  })
